<?php
/*
Plugin Name: Enhanced Content Protection (EasyToolsWP)
Description: This plugin prevents right-clicking, text selection and copying on the front end.
Version: 1.2
Author: EasyToolsWP.com
Author URI: https://www.easytoolswp.com
*/

// Function to add settings menu
function easytoolswp_menu() {
    add_submenu_page(
        '', 
        'Enhanced Content Protection Settings', 
        'Enhanced Content Protection', 
        'manage_options', 
        'easytoolswp_pro-settings', 
        'easytoolswp_pro_settings_page'
    );
}
add_action('admin_menu', 'easytoolswp_menu');

// Function to render the settings page
function easytoolswp_pro_settings_page() {
    ?>
    <div class="wrap">
        <h1>Enhanced Content Protection Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('easytoolswp_pro_settings_group');
            do_settings_sections('easytoolswp_pro-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Function to register settings
function easytoolswp_pro_settings_init() {
    register_setting('easytoolswp_pro_settings_group', 'easytoolswp_pro_enabled');

    add_settings_section(
        'easytoolswp_pro_settings_section', 
        'Settings', 
        'easytoolswp_pro_settings_section_callback', 
        'easytoolswp_pro-settings'
    );

    add_settings_field(
        'easytoolswp_pro_enabled', 
        'Enable Enhanced Content Protection', 
        'easytoolswp_pro_enabled_callback', 
        'easytoolswp_pro-settings', 
        'easytoolswp_pro_settings_section'
    );
}
add_action('admin_init', 'easytoolswp_pro_settings_init');

// Callback functions
function easytoolswp_pro_settings_section_callback() {
    echo 'Enable or disable the enhanced content protection.';
}

function easytoolswp_pro_enabled_callback() {
    $option = get_option('easytoolswp_pro_enabled');
    echo '<input type="checkbox" id="easytoolswp_pro_enabled" name="easytoolswp_pro_enabled" value="1" ' . checked(1, $option, false) . '/>';
}

// Function to add the content protection if enabled
function enhanced_content_protection() {
    if (get_option('easytoolswp_pro_enabled')) {
        echo '<style>
            /* Deaktiver tekstmarkering */
            body {
                -webkit-user-select: none; /* Safari */
                -moz-user-select: none; /* Firefox */
                -ms-user-select: none; /* Internet Explorer/Edge */
                user-select: none; /* Standard */
            }

            /* Beskyt billeder ved at forhindre træk og drop */
            img {
                -webkit-user-drag: none;
                -khtml-user-drag: none;
                -moz-user-drag: none;
                -o-user-drag: none;
                user-drag: none;
            }
        </style>
        <script type="text/javascript">
            // Forhindre højreklik
            document.addEventListener("contextmenu", function(e) {
                e.preventDefault();
            }, false);

            // Forhindre kopiering
            document.addEventListener("copy", function(e) {
                e.preventDefault();
            }, false);

            // Forhindre træk og drop af billeder
            document.addEventListener("dragstart", function(e) {
                if (e.target.nodeName.toUpperCase() === "IMG") {
                    e.preventDefault();
                }
            }, false);
        </script>';
    }
}
add_action('wp_footer', 'enhanced_content_protection');
?>
